@@ -1,6 +1,6 @@
 """Language models for astrochemistry."""
 
-from astrochem_embedding.utils import get_paths, Translator
+from astrochem_embedding.utils import get_paths, Translator, get_pretrained_path
 from astrochem_embedding import models, pipeline, layers
 
 from astrochem_embedding.models.models import VICGAE, GRUAutoEncoder
